ChangeToEndOfLine

Struct ChangeToEndOfLine 

pub struct ChangeToEndOfLine;
Change to end of line (C).

Deletes from cursor to end of line and enters insert mode. The deleted text is stored in the register as characterwise.