pub struct ChangeCommand;Expand description
Change operator command - wraps ChangeOperator for command execution.
This command is executed by the runner when PopResult::ExecuteCommand
is received with command vim:change. It reads the range from the
command context, deletes the text, and transitions to insert mode.