pub struct VimModuleProviderExt;Expand description
Marker struct for implementing DefaultModeProviderModule on VimModule.
This is used internally to provide the companion trait implementation.
Implementations
Sourceimpl VimModuleProviderExt
impl VimModuleProviderExt
Sourcepub fn default_mode_provider() -> Option<Arc<dyn DefaultModeProvider>>
pub fn default_mode_provider() -> Option<Arc<dyn DefaultModeProvider>>
Get the default mode provider for the Vim module.