pub struct OperatorId { /* private fields */ }Expand description
Namespaced operator identifier.
Operators are identified by their owning module and a local name. This prevents naming conflicts between modules and provides type-safe operator references instead of string-based identification.
Note
Operators (d, y, c) are vim-specific policy. The kernel has ZERO vim knowledge - this type lives in the vim module, not the kernel.
Example
use reovim_module_vim::ids::{OperatorId, MODULE, DELETE};
let delete = OperatorId::new(MODULE, "delete");
assert_eq!(delete.name(), "delete");
assert_eq!(delete.module().as_str(), "vim");
// Or use the pre-defined constant
assert_eq!(DELETE.name(), "delete");Implementations
Sourceimpl OperatorId
impl OperatorId
Sourcepub const fn new(module: ModuleId, name: &'static str) -> Self
pub const fn new(module: ModuleId, name: &'static str) -> Self
Create a new operator identifier from static strings.
Sourcepub fn from_qualified(qualified: String) -> Self
pub fn from_qualified(qualified: String) -> Self
Create an operator identifier from a qualified string like “module:operator”.
This method is intended for dynamic use cases like FFI where operator IDs are specified as strings at runtime.
If the string doesn’t contain ‘:’, the entire string is treated as the operator name with “unknown” as the module.
Sourcepub fn name_owned(&self) -> Cow<'static, str>
pub fn name_owned(&self) -> Cow<'static, str>
Get the local name as an owned Cow.