pub struct LastChange {
pub change_type: ChangeType,
pub count: Option<usize>,
pub register: Option<char>,
pub keys: Vec<KeyEvent>,
}Expand description
Record of the last change for dot repeat (.).
Stores information needed to replay the last edit operation. This is set by operator resolvers and insert mode exit.
Fields
change_type: ChangeTypeType of change that was made.
count: Option<usize>Count used with the original command (None = no explicit count).
register: Option<char>Register used with the original command.
keys: Vec<KeyEvent>Recorded key sequence for replay via InjectKeys (#577).
When non-empty, . replays these keys instead of using the
metadata-based approach. This handles all cases including
operator+motion, operator+textobj, and change+insert.